# v1.1.0

  * Moved repository to https://github.com/Nexmo/nexmo-python

  * Added `get_basic_number_insight` method for Number Insight Basic API

  * Added `get_number_insight` method for Number Insight Standard API

  * Added User-Agent header to requests

# v1.0.3

  * Changed license from LGPL-3.0 to MIT

# v1.0.2

  * Removed merge helper function

# v1.0.1

  * Python 3.x fixes

# v1.0.0

  * First version!
